package com.qs.mp.admin.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.qs.mp.admin.domain.Coupon;
import com.qs.mp.admin.domain.Ticket;
import com.qs.mp.admin.mapper.CouponMapper;
import com.qs.mp.admin.service.ICouponService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qs.mp.common.enums.CouponUseAreaEnum;
import com.qs.mp.common.enums.UserCouponStatusEnum;
import com.qs.mp.common.exception.ServiceException;
import com.qs.mp.common.utils.DateUtils;
import com.qs.mp.common.utils.LogUtil;
import com.qs.mp.system.service.id.BizIdGenerator;
import com.qs.mp.user.domain.UserCoupon;
import com.qs.mp.user.domain.UserCouponChannel;
import com.qs.mp.user.domain.UserTicketOrderItem;
import com.qs.mp.user.service.IUserCouponChannelService;
import com.qs.mp.user.service.IUserCouponService;
import com.qs.mp.user.service.IUserTicketOrderItemService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 优惠券 服务实现类
 * </p>
 *
 * @author quanshu
 * @since 2022-03-07
 */
@Service
public class CouponServiceImpl extends ServiceImpl<CouponMapper, Coupon> implements ICouponService {

  protected final Logger logger = LoggerFactory.getLogger(this.getClass());

  @Autowired
  private IUserCouponService userCouponService;

  @Autowired
  private IUserCouponChannelService userCouponChannelService;

  @Autowired
  private BizIdGenerator bizIdGenerator;

  @Autowired
  private IUserTicketOrderItemService userTicketOrderItemService;

  @Override
  @Transactional
  public void distribute(Ticket ticket, Long userId, String couponId) {
    Coupon coupon = getById(couponId);
    UserCoupon userCoupon = new UserCoupon();
    userCoupon.setId(bizIdGenerator.newId());
    userCoupon.setUserId(userId);
    userCoupon.setVerifyCode(bizIdGenerator.newId());
    userCoupon.setCouponId(coupon.getCouponId());
    if (coupon.getDueDays() > 0) {
      userCoupon.setValidStart(DateUtils.getToday());
      userCoupon.setValidEnd(DateUtils.addDays(userCoupon.getValidStart(), coupon.getDueDays()));
    } else {
      userCoupon.setValidStart(coupon.getValidStart());
      userCoupon.setValidEnd(coupon.getValidEnd());
    }
    userCoupon.setStatus(UserCouponStatusEnum.UNUSED);
    userCouponService.save(userCoupon);

    // 确定限定范围
    if (coupon.getUseArea() == CouponUseAreaEnum.POST_SCOPE) {
      UserTicketOrderItem orderItem = userTicketOrderItemService.queryFinishedOrderItem(userId, ticket.getTicketId());
      if (null == orderItem || null == orderItem.getChannelId()) {
        LogUtil.error(logger, "优惠券的限定使用范围类型为发放时生成，但找不到关联的渠道ID。orderItem:{0}", new Object[]{
            JSONObject.toJSONString(orderItem)});
        throw new ServiceException("优惠券发放失败");
      }
      UserCouponChannel userCouponChannel = new UserCouponChannel();
      userCouponChannel.setUserCouponId(userCoupon.getId());
      userCouponChannel.setChannelId(orderItem.getChannelId());
      userCouponChannelService.save(userCouponChannel);
    }
  }
}
