package com.qs.mp.channel.domain;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.qs.mp.common.enums.ChannelCertifyStatusEnum;
import com.qs.mp.common.enums.ChannelStatusEnum;
import com.qs.mp.common.enums.ChannelVerifyStatusEnum;
import com.qs.mp.common.enums.SiteTypeEnum;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import lombok.Data;

/**
 * @describe 渠道经销商实体类
 * @auther quanshu
 * @create 2022-03-02 12:22:24
 */
@TableName("mp_channel")
@Data
public class Channel implements Serializable {

  private static final long serialVersionUID = 1L;

  /**
   * 主键
   */
  @TableId(value = "channel_id" , type = IdType.AUTO)
  private Long channelId;

  /**
   * 渠道编码
   */
  @TableField("channel_no")
  private String channelNo;

  /**
   * 渠道名称
   */
  @TableField("name")
  private String name;

  /**
   * 父渠道ID
   */
  @TableField("parent_id")
  private Long parentId;

  /**
   * 渠道级别，0:经销商；1:一级渠道；2:二级渠道
   */
  @TableField("level")
  private Integer level;

  /**
   * 经销商类型
   */
  @TableField("site_type")
  @JSONField(serialzeFeatures = SerializerFeature.WriteEnumUsingToString)
  private SiteTypeEnum siteType;

  /**
   * 分佣百分比
   */
  @TableField("comm_rate")
  private BigDecimal commRate;

  /**
   * 省ID
   */
  @TableField("province_id")
  private Long provinceId;

  /**
   * 省
   */
  @TableField("province")
  private String province;

  /**
   * 城市
   */
  @TableField("city")
  private String city;

  /**
   * 城市ID
   */
  @TableField("city_id")
  private Long cityId;

  /**
   * 区
   */
  @TableField("area")
  private String area;

  /**
   * 区ID
   */
  @TableField("area_id")
  private Long areaId;

  /**
   * 详细地址
   */
  @TableField("address")
  private String address;

  /**
   * 联系人
   */
  @TableField("contact")
  private String contact;

  /**
   * 手机号
   */
  @TableField("mobile")
  private String mobile;

  /**
   * 用户ID
   */
  @TableField("user_id")
  private Long userId;

  /**
   * 账户余额
   */
  @TableField("money")
  private Integer money;

  /**
   * 账户冻结金额
   */
  @TableField("frozen_money")
  private Integer frozenMoney;

  /**
   * 认证状态，未认证n，已认证y
   */
  @TableField("certify_status")
  @JSONField(serialzeFeatures = SerializerFeature.WriteEnumUsingToString)
  private ChannelCertifyStatusEnum certifyStatus;

  /**
   * 审核状态
   */
  @TableField("verify_status")
  @JSONField(serialzeFeatures = SerializerFeature.WriteEnumUsingToString)
  private ChannelVerifyStatusEnum verifyStatus;

  /**
   * 营业执照
   */
  @TableField("biz_license_pic")
  private String bizLicensePic;

  /**
   * 门头照片
   */
  @TableField("door_pic")
  private String doorPic;

  /**
   * 备注信息
   */
  @TableField("memo")
  private String memo;

  /**
   * 状态，启用、停用
   */
  @TableField("status")
  @JSONField(serialzeFeatures = SerializerFeature.WriteEnumUsingToString)
  private ChannelStatusEnum status;

  /**
   * 创建时间
   */
  @TableField("created_time")
  private Date createdTime;

  /**
   * 更新时间
   */
  @TableField("updated_time")
  private Date updatedTime;


}
