package com.qs.mp.channel.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.qs.mp.channel.domain.Channel;
import com.qs.mp.channel.domain.ChannelBankCard;
import com.qs.mp.channel.domain.ChannelWithdraw;
import com.qs.mp.channel.mapper.ChannelWithdrawMapper;
import com.qs.mp.channel.service.IChannelBankCardService;
import com.qs.mp.channel.service.IChannelService;
import com.qs.mp.channel.service.IChannelWithdrawService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 渠道提现表 服务实现类
 * </p>
 *
 * @author quanshu
 * @since 2022-03-04
 */
@Service
public class ChannelWithdrawServiceImpl extends ServiceImpl<ChannelWithdrawMapper, ChannelWithdraw> implements IChannelWithdrawService {

  @Autowired
  private IChannelBankCardService channelBankCardService;

  @Autowired
  private IChannelService channelService;

  @Override
  @Transactional
  public boolean apply(Channel channel, ChannelWithdraw channelWithdraw) {
    // 更新用户的银行卡信息
    ChannelBankCard bankCard = channelBankCardService.getOne(new LambdaQueryWrapper<ChannelBankCard>()
        .eq(ChannelBankCard::getChannelId, channel.getChannelId()));
    if (null == bankCard) {
      bankCard = new ChannelBankCard();
      bankCard.setCardNo(channelWithdraw.getCardNo());
      bankCard.setBankName(channelWithdraw.getBankName());
      bankCard.setBranchName(channelWithdraw.getBranchName());
      bankCard.setUserName(channelWithdraw.getUserName());
      channelBankCardService.save(bankCard);
    } else {
      bankCard.setCardNo(channelWithdraw.getCardNo());
      bankCard.setBankName(channelWithdraw.getBankName());
      bankCard.setBranchName(channelWithdraw.getBranchName());
      bankCard.setUserName(channelWithdraw.getUserName());
      channelBankCardService.updateById(bankCard);
    }

    // 冻结账户余额，乐观锁
    channelService.update(new LambdaUpdateWrapper<Channel>()
        .set(Channel::getFrozenMoney, channel.getFrozenMoney() + channelWithdraw.getMoney())
        .set(Channel::getMoney, channel.getMoney() - channelWithdraw.getMoney())
        .eq(Channel::getChannelId, channel.getChannelId()).eq(Channel::getMoney, channel.getMoney()));

    // 创建提现记录
    return save(channelWithdraw);
  }
}
