package com.qs.mp.framework.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.qs.mp.common.exception.ServiceException;
import com.qs.mp.common.utils.DateUtils;
import com.qs.mp.common.utils.LogUtil;
import com.qs.mp.common.utils.StringUtils;
import com.qs.mp.common.utils.http.HttpUtils;
import com.qs.mp.framework.domain.AppToken;
import com.qs.mp.framework.mapper.AppTokenMapper;
import com.qs.mp.framework.redis.RedisKey;
import com.qs.mp.framework.redis.RedisKeyBuilder;
import com.qs.mp.framework.redis.RedisUtil;
import com.qs.mp.framework.service.IAppTokenService;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AppTokenServiceImpl implements IAppTokenService {
    protected final Logger logger = LoggerFactory.getLogger(AppTokenServiceImpl.class);

    @Autowired
    private AppTokenMapper appTokenMapper;


    @Autowired
    private RedisUtil redis;
    
    @Override
    public AppToken selectByPrimaryKey(String appId) {
        return appTokenMapper.selectByPrimaryKey(appId);
    }

    @Override
    public String getAccessToken(String appId) {
        Map<String, String> keyParams = new HashMap<String, String>();
        keyParams.put("appId", appId);
        String cacheKey = RedisKeyBuilder.build(RedisKey.App_Secret_Key, keyParams);

        boolean updateCache = false;

        String appInfo = redis.get(cacheKey);
        AppToken token = null;
        if (StringUtils.isBlank(appInfo)) {
            token = selectByPrimaryKey(appId);
            if (null == token) {
                LogUtil.error(logger, "app_token记录不存在，appId:{0}", appId);
                throw new ServiceException();
            }
            updateCache = true;
        } else {
            token = JSON.parseObject(appInfo, AppToken.class);
        }

        LogUtil.info(logger, "token: {0}", JSON.toJSONString(token));
        if (token.getExpireTimestamp().getTime() < System.currentTimeMillis()) {
            String res = wxGetAccessToken(appId, token.getAppSecret());
            if (StringUtils.isEmpty(res)){
                LogUtil.error(logger, "获取access_token为空，appId:{0}, res:{1}", new Object[]{appId,
                                                                                          res});
                throw new ServiceException();
            }
            JSONObject jsonObject = JSONObject.parseObject(res);
            String accessToken = jsonObject.getString("access_token");
            Integer expiresIn = jsonObject.getInteger("expires_in");
            if(StringUtils.isEmpty(accessToken)){
                LogUtil.error(logger, "获取access_token为空，appId:{0}, res:{1}",
                        new Object[] { appId, res });
                throw new ServiceException();
            }
            token.setAccessToken(accessToken);
            // 防止时间不同步，此处提前100s超时
            token.setExpireTimestamp(DateUtils.addSeconds(new Date(), expiresIn-100));
            appTokenMapper.updateByPrimaryKeySelective(token);
            updateCache = true;

        }

        if(updateCache) {
            boolean result = redis.set(cacheKey, JSON.toJSONString(token));
            if (!result) {
                LogUtil.error(logger, "appsecret key set error.cacheKey:", cacheKey);
            }
        }



        return token.getAccessToken();
    }

    private String wxGetAccessToken(String appId, String appSecret) {
        String param = "appid=" + appId + "&secret=" + appSecret + "&grant_type=client_credential";
        String res = HttpUtils.sendGet("https://api.weixin.qq.com/cgi-bin/token", param);
        return res;

    }

}
