package com.qs.mp.framework.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.qs.mp.common.utils.LogUtil;
import com.qs.mp.common.utils.http.HttpUtils;
import com.qs.mp.framework.service.IAppTokenService;
import com.qs.mp.framework.service.IWxUrlLinkService;
import java.util.HashMap;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

/**
 * 微信小程序链接生成
 *
 * @author zhongcp
 * @Date 2021/9/22
 */
@Service
public class WxUrlLinkServiceImpl implements IWxUrlLinkService {

  protected final Logger logger = LoggerFactory.getLogger(WxUrlLinkServiceImpl.class);

  @Autowired
  private IAppTokenService appTokenService;

  @Value("${wx-channel.appId}")
  private String channelAppId;

  @Override
  public String generate(String path, String query) {
    Map<String, Object> param = new HashMap<String, Object>();
    param.put("path", path);
    param.put("query", query);
    // 有效时间超过31天的 Link 或永久有效的 Link 为长期有效Link，
    // 单个小程序总共可生成长期有效 Link 上限为10万个，请谨慎调用
    param.put("is_expire", true);
    param.put("expire_type", 1);
    param.put("expire_interval", 30);
    // 云管铺小程序永久短链接https://wxaurl.cn/YL8D48CQbMr
    // 获取access_token
    String accessToken = appTokenService.getAccessToken(channelAppId);
    String res = HttpUtils.sendPost(
        "https://api.weixin.qq.com/wxa/generate_urllink?access_token=" + accessToken,
        JSON.toJSONString(param));
    LogUtil.info(logger, "小程序链接获取,path:{0},query:{1},res:{2}",
        new Object[]{path, query, res});
    JSONObject jsonObject = JSON.parseObject(res);
    if (jsonObject.getIntValue("errcode") != 0) {
      LogUtil.error(logger, "小程序链接获取错误，res:{0}", res);
      return null;
    }
    return jsonObject.getString("url_link");
  }
}
